@@ -2,6 +2,7 @@ class DatapointDatamodel:
     def __init__(self):
         self._expected_label = None
         self._predicted_label = None
+        self._loss = None
         self._context = None
 
     def expected_label(self):
@@ -10,6 +11,9 @@ class DatapointDatamodel:
     def predicted_label(self):
         return self._predicted_label
 
+    def loss(self):
+        return self._loss
+
     def context(self):
         return self._context
 
@@ -19,6 +23,9 @@ class DatapointDatamodel:
     def set_predicted_label(self, predicted_label):
         self._predicted_label = predicted_label
 
+    def set_loss(self, loss):
+        self._loss = loss
+
     def set_context(self, context):
         self._context = context
 
@@ -27,14 +34,16 @@ class DatapointDatamodel:
         datapoint = DatapointDatamodel()
         datapoint.set_expected_label(val['expected_label'])
         datapoint.set_predicted_label(val['predicted_label'])
+        datapoint.set_loss(val['loss'])
         datapoint.set_context(val['context'])
         return datapoint
 
     @staticmethod
-    def create(expected_label, predicted_label, context):
+    def create(expected_label, predicted_label, loss, context):
         datapoint = DatapointDatamodel()
         datapoint.set_expected_label(expected_label)
         datapoint.set_predicted_label(predicted_label)
+        datapoint.set_loss(loss)
         datapoint.set_context(context)
         return datapoint
 
@@ -42,5 +51,6 @@ class DatapointDatamodel:
         return {
             'expected_label': self.expected_label(),
             'predicted_label': self.predicted_label(),
+            'loss': self.loss(),
             'context': self.context(),
-        }
\ No newline at end of file
+        }
